@@ -1,15 +1,16 @@
-import os
-from voluptuous import *
+from os import path
+from six import string_types
+from voluptuous import All, Any, Boolean, Coerce, Optional, Range, Required
 
 # Elasticsearch versions supported
 def version_max():
-    return (5, 99, 99)
+    return (7, 99, 99)
 def version_min():
     return (5, 0, 0)
 
 # Default Config file location
 def config_file():
-    return os.path.join(os.path.expanduser('~'), '.curator', 'curator.yml')
+    return path.join(path.expanduser('~'), '.curator', 'curator.yml')
 
 # Default filter patterns (regular expressions)
 def regex_map():
@@ -49,6 +50,7 @@ def index_actions():
         'create_index',
         'delete_indices',
         'forcemerge',
+        'freeze',
         'index_settings',
         'open',
         'reindex',
@@ -56,6 +58,7 @@ def index_actions():
         'rollover',
         'shrink',
         'snapshot',
+        'unfreeze',
     ]
 
 def snapshot_actions():
@@ -71,13 +74,16 @@ def index_filtertypes():
         'age',
         'closed',
         'count',
+        'empty',
         'forcemerged',
+        'ilm',
         'kibana',
         'none',
         'opened',
         'pattern',
         'period',
         'space',
+        'shards'
     ]
 
 def snapshot_filtertypes():
@@ -88,6 +94,7 @@ def all_filtertypes():
 
 def default_options():
     return {
+        'allow_ilm_indices': False,
         'continue_if_exception': False,
         'disable_action': False,
         'ignore_empty_list': False,
@@ -98,29 +105,40 @@ def default_filters():
     return { 'filters' : [{ 'filtertype' : 'none' }] }
 
 def structural_filter_elements():
+    # pylint: disable=E1120
     return {
-        Optional('aliases'): Any(str, [str], unicode, [unicode]),
-        Optional('allocation_type'): Any(str, unicode),
+        Optional('aliases'): Any(list, *string_types),
+        Optional('allocation_type'): Any(*string_types),
         Optional('count'): Coerce(int),
-        Optional('direction'): Any(str, unicode),
+        Optional('date_from'): Any(None, *string_types),
+        Optional('date_from_format'): Any(None, *string_types),
+        Optional('date_to'): Any(None, *string_types),
+        Optional('date_to_format'): Any(None, *string_types),
+        Optional('direction'): Any(*string_types),
         Optional('disk_space'): float,
         Optional('epoch'): Any(Coerce(int), None),
-        Optional('exclude'): Any(int, str, unicode, bool, None),
-        Optional('field'): Any(str, unicode, None),
-        Optional('key'): Any(str, unicode),
-        Optional('kind'): Any(str, unicode),
+        Optional('exclude'): Any(None, bool, int, *string_types),
+        Optional('field'): Any(None, *string_types),
+        Optional('intersect'): Any(None, bool, int, *string_types),
+        Optional('key'): Any(*string_types),
+        Optional('kind'): Any(*string_types),
         Optional('max_num_segments'): Coerce(int),
-        Optional('reverse'): Any(int, str, unicode, bool, None),
+        Optional('number_of_shards'): Coerce(int),
+        Optional('pattern'): Any(*string_types),
+        Optional('period_type'): Any(*string_types),
+        Optional('reverse'): Any(None, bool, int, *string_types),
         Optional('range_from'): Coerce(int),
         Optional('range_to'): Coerce(int),
-        Optional('source'): Any(str, unicode),
-        Optional('state'): Any(str, unicode),
-        Optional('stats_result'): Any(str, unicode, None),
-        Optional('timestring'): Any(str, unicode, None),
-        Optional('unit'): Any(str, unicode),
+        Optional('shard_filter_behavior'): Any(*string_types),
+        Optional('source'): Any(*string_types),
+        Optional('state'): Any(*string_types),
+        Optional('stats_result'): Any(None, *string_types),
+        Optional('timestring'): Any(None, *string_types),
+        Optional('threshold_behavior'): Any(*string_types),
+        Optional('unit'): Any(*string_types),
         Optional('unit_count'): Coerce(int),
-        Optional('unit_count_pattern'): Any(str, unicode),
+        Optional('unit_count_pattern'): Any(*string_types),
         Optional('use_age'): Boolean(),
-        Optional('value'): Any(int, float, str, unicode, bool),
-        Optional('week_starts_on'): Any(str, unicode, None),
-    }
\ No newline at end of file
+        Optional('value'): Any(int, float, bool, *string_types),
+        Optional('week_starts_on'): Any(None, *string_types),
+    }
