@@ -275,6 +275,29 @@ allocation_test = ('---\n'
 '        kind: prefix\n'
 '        value: my\n')
 
+
+allocation_count_test = ('---\n'
+'actions:\n'
+'  1:\n'
+'    description: "Allocate by key/value/allocation_type"\n'
+'    action: allocation\n'
+'    options:\n'
+'      key: {0}\n'
+'      value: {1}\n'
+'      allocation_type: {2}\n'
+'      wait_for_completion: {3}\n'
+'      wait_interval: 1\n'
+'      max_wait: -1\n'
+'      continue_if_exception: False\n'
+'      disable_action: False\n'
+'    filters:\n'
+'      - filtertype: count\n'
+'        use_age: True\n'
+'        source: name\n'
+'        timestring: \'%Y.%m.%d\'\n'
+'        count: 2\n'
+'        exclude: False\n')
+
 cluster_routing_test = ('---\n'
 'actions:\n'
 '  1:\n'
@@ -374,6 +397,32 @@ close_delete_aliases = ('---\n'
 '        kind: prefix\n'
 '        value: my\n')
 
+close_skip_flush = ('---\n'
+'actions:\n'
+'  1:\n'
+'    description: "Close indices as filtered"\n'
+'    action: close\n'
+'    options:\n'
+'      skip_flush: True\n'
+'      continue_if_exception: False\n'
+'      disable_action: False\n'
+'    filters:\n'
+'      - filtertype: pattern\n'
+'        kind: prefix\n'
+'        value: my\n')
+
+close_ignore_sync = ('---\n'
+'actions:\n'
+'  1:\n'
+'    description: "Close indices as filtered"\n'
+'    action: close\n'
+'    options:\n'
+'      ignore_sync_failures: {0}\n'
+'    filters:\n'
+'      - filtertype: pattern\n'
+'        kind: prefix\n'
+'        value: my\n')
+
 delete_proto = ('---\n'
 'actions:\n'
 '  1:\n'
@@ -410,6 +459,7 @@ delete_pattern_proto = ('---\n'
                 '        unit_count: {5}\n'
                 '        unit_count_pattern: {6}\n')
 
+
 delete_period_proto = ('---\n'
 'actions:\n'
 '  1:\n'
@@ -427,8 +477,9 @@ delete_period_proto = ('---\n'
 '      unit: {5}\n'
 '      field: {6}\n'
 '      stats_result: {7}\n'
-'      epoch: {8}\n'
-'      week_starts_on: {9}\n')
+'      intersect: {8}\n'
+'      epoch: {9}\n'
+'      week_starts_on: {10}\n')
 
 delete_ignore_proto = ('---\n'
 'actions:\n'
@@ -557,8 +608,9 @@ create_index_with_extra_settings = ('---\n'
 '    options:\n'
 '      name: {0}\n'
 '      extra_settings:\n'
-'        number_of_shards: 1\n'
-'        number_of_replicas: 0\n'
+'        settings:\n'
+'          number_of_shards: 1\n'
+'          number_of_replicas: 0\n'
 '      continue_if_exception: False\n'
 '      disable_action: False\n')
 
@@ -740,6 +792,7 @@ reindex = ('---\n'
 '    description: "Reindex"\n'
 '    action: reindex\n'
 '    options:\n'
+'      allow_ilm_indices: true\n'
 '      wait_interval: {0}\n'
 '      max_wait: {1}\n'
 '      request_body:\n'
@@ -749,6 +802,26 @@ reindex = ('---\n'
 '          index: {3}\n'
 '    filters:\n'
 '    - filtertype: none\n')
+
+reindex_empty_list = ('---\n'
+'actions:\n'
+'  1:\n'
+'    description: "Reindex"\n'
+'    action: reindex\n'
+'    options:\n'
+'      ignore_empty_list: {0}\n'
+'      wait_interval: {1}\n'
+'      max_wait: {2}\n'
+'      request_body:\n'
+'        source:\n'
+'          index: REINDEX_SELECTED\n'
+'        dest:\n'
+'          index: {3}\n'
+'    filters:\n'
+'    - filtertype: pattern\n'
+'      kind: prefix\n'
+'      value: notfound\n')
+
 remote_reindex = ('---\n'
 'actions:\n'
 '  1:\n'
@@ -826,4 +899,22 @@ index_settings = ('---\n'
 '    filters:\n'
 '      - filtertype: pattern\n'
 '        kind: prefix\n'
-'        value: my\n')
\ No newline at end of file
+'        value: my\n')
+
+ilm_delete_proto = ('---\n'
+'actions:\n'
+'  1:\n'
+'    description: "Delete indices as filtered"\n'
+'    action: delete_indices\n'
+'    options:\n'
+'      allow_ilm_indices: {9}\n'
+'    filters:\n'
+'      - filtertype: {0}\n'
+'        source: {1}\n'
+'        direction: {2}\n'
+'        timestring: {3}\n'
+'        unit: {4}\n'
+'        unit_count: {5}\n'
+'        field: {6}\n'
+'        stats_result: {7}\n'
+'        epoch: {8}\n')
