@@ -143,16 +143,18 @@ class TestGetDateRegex(TestCase):
 class TestFixEpoch(TestCase):
     def test_fix_epoch(self):
         for long_epoch, epoch in [
+            (1459287636, 1459287636),
+            (14592876369, 14592876),
+            (145928763699, 145928763),
             (1459287636999, 1459287636),
             (1459287636000000, 1459287636),
             (145928763600000000, 1459287636),
             (145928763600000001, 1459287636),
             (1459287636123456789, 1459287636),
-            (1459287636999, 1459287636),
                 ]:
             self.assertEqual(epoch, curator.fix_epoch(long_epoch))
     def test_fix_epoch_raise(self):
-        self.assertRaises(ValueError, curator.fix_epoch, 12345678901)
+            self.assertRaises(ValueError, curator.fix_epoch, None)
 
 class TestGetPointOfReference(TestCase):
     def test_get_point_of_reference(self):
@@ -225,7 +227,7 @@ class TestCheckVersion(TestCase):
         self.assertRaises(curator.CuratorException, curator.check_version, client)
     def test_check_version_greater_than(self):
         client = Mock()
-        client.info.return_value = {'version': {'number': '6.0.1'} }
+        client.info.return_value = {'version': {'number': '8.0.1'} }
         self.assertRaises(curator.CuratorException, curator.check_version, client)
 
 class TestCheckMaster(TestCase):
@@ -258,7 +260,7 @@ class TestGetClient(TestCase):
             'url_prefix': None, 'use_ssl' : True, 'ssl_no_validate' : True
         }
         self.assertRaises(
-            elasticsearch.ElasticsearchException,
+            curator.ClientException,
             curator.get_client, **kwargs
         )
     def test_url_prefix_none_str(self):
@@ -266,7 +268,7 @@ class TestGetClient(TestCase):
             'url_prefix': 'None', 'use_ssl' : True, 'ssl_no_validate' : True
         }
         self.assertRaises(
-            elasticsearch.ElasticsearchException,
+            curator.ClientException,
             curator.get_client, **kwargs
         )
     def test_master_only_multiple_hosts(self):
@@ -291,28 +293,38 @@ class TestGetClient(TestCase):
     def test_certificate_logic(self):
         kwargs = { 'use_ssl' : True, 'certificate' : 'mycert.pem' }
         self.assertRaises(
-            elasticsearch.ElasticsearchException,
+            curator.ClientException,
             curator.get_client, **kwargs
         )
     def test_client_cert_logic(self):
         kwargs = { 'use_ssl' : True, 'client_cert' : 'myclientcert.pem' }
         self.assertRaises(
-            elasticsearch.ElasticsearchException,
+            curator.ClientException,
             curator.get_client, **kwargs
         )
     def test_client_key_logic(self):
         kwargs = { 'use_ssl' : True, 'client_key' : 'myclientkey.pem' }
         self.assertRaises(
-            elasticsearch.ElasticsearchException,
+            curator.ClientException,
             curator.get_client, **kwargs
         )
     def test_certificate_no_verify_logic(self):
         kwargs = { 'use_ssl' : True, 'ssl_no_validate' : True }
         self.assertRaises(
-            elasticsearch.ElasticsearchException,
+            curator.ClientException,
             curator.get_client, **kwargs
         )
 
+    def test_api_key_not_set(self):
+        kwargs = { 'api_key': None }
+        self.assertIsNotNone(curator.get_client(**kwargs))
+
+    def test_api_key_set(self):
+        kwargs = { 'api_key': 'some-api-key' }
+        client = curator.get_client(**kwargs)
+        self.assertEqual('some-api-key', client.transport.kwargs['headers']['x-api-key'])
+
+
 class TestShowDryRun(TestCase):
     # For now, since it's a pain to capture logging output, this is just a
     # simple code coverage run
@@ -642,23 +654,28 @@ class TestVerifyClientObject(TestCase):
 class TestRollableAlias(TestCase):
     def test_return_false_if_no_alias(self):
         client = Mock()
+        client.info.return_value = {'version': {'number': '6.6.3'} }
         client.indices.get_alias.return_value = {}
         client.indices.get_alias.side_effect = elasticsearch.NotFoundError
         self.assertFalse(curator.rollable_alias(client, 'foo'))
     def test_return_false_too_many_indices(self):
         client = Mock()
+        client.info.return_value = {'version': {'number': '6.6.3'} }
         client.indices.get_alias.return_value = testvars.not_rollable_multiple
         self.assertFalse(curator.rollable_alias(client, 'foo'))
     def test_return_false_non_numeric(self):
         client = Mock()
+        client.info.return_value = {'version': {'number': '6.6.3'} }
         client.indices.get_alias.return_value = testvars.not_rollable_non_numeric
         self.assertFalse(curator.rollable_alias(client, 'foo'))
     def test_return_true_two_digits(self):
         client = Mock()
+        client.info.return_value = {'version': {'number': '6.6.3'} }
         client.indices.get_alias.return_value = testvars.is_rollable_2digits
         self.assertTrue(curator.rollable_alias(client, 'foo'))
     def test_return_true_hypenated(self):
         client = Mock()
+        client.info.return_value = {'version': {'number': '6.6.3'} }
         client.indices.get_alias.return_value = testvars.is_rollable_hypenated
         self.assertTrue(curator.rollable_alias(client, 'foo'))
 
@@ -1066,6 +1083,150 @@ class TestDateRange(TestCase):
         self.assertEqual((start,end), 
             curator.date_range(unit, range_from, range_to, epoch=epoch))
 
+class TestAbsoluteDateRange(TestCase):
+    def test_bad_unit(self):
+        unit = 'invalid'
+        date_from = '2017.01'
+        date_from_format = '%Y.%m'
+        date_to = '2017.01'
+        date_to_format = '%Y.%m'
+        self.assertRaises(
+            curator.ConfigurationError,
+            curator.absolute_date_range, unit, date_from, date_to, date_from_format, date_to_format
+        )
+    def test_bad_formats(self):
+        unit = 'days'
+        self.assertRaises(
+            curator.ConfigurationError,
+            curator.absolute_date_range, unit, 'meh', 'meh', None, 'meh'
+        )
+        self.assertRaises(
+            curator.ConfigurationError,
+            curator.absolute_date_range, unit, 'meh', 'meh', 'meh', None
+        )
+    def test_bad_dates(self):
+        unit = 'weeks'
+        date_from_format = '%Y.%m'
+        date_to_format = '%Y.%m'
+        self.assertRaises(
+            curator.ConfigurationError,
+            curator.absolute_date_range, unit, 'meh', '2017.01', date_from_format, date_to_format
+        )
+        self.assertRaises(
+            curator.ConfigurationError,
+            curator.absolute_date_range, unit, '2017.01', 'meh', date_from_format, date_to_format
+        )
+    def test_single_month(self):
+        unit = 'months'
+        date_from = '2017.01'
+        date_from_format = '%Y.%m'
+        date_to = '2017.01'
+        date_to_format = '%Y.%m'
+        start = curator.datetime_to_epoch(datetime(2017,  1,  1,  0,  0,  0))
+        end   = curator.datetime_to_epoch(datetime(2017,  1, 31, 23, 59, 59))
+        self.assertEqual((start,end),
+            curator.absolute_date_range(unit, date_from, date_to, date_from_format, date_to_format))
+    def test_multiple_month(self):
+        unit = 'months'
+        date_from = '2016.11'
+        date_from_format = '%Y.%m'
+        date_to = '2016.12'
+        date_to_format = '%Y.%m'
+        start = curator.datetime_to_epoch(datetime(2016, 11,  1,  0,  0,  0))
+        end   = curator.datetime_to_epoch(datetime(2016, 12, 31, 23, 59, 59))
+        self.assertEqual((start,end),
+            curator.absolute_date_range(unit, date_from, date_to, date_from_format, date_to_format))
+    def test_single_year(self):
+        unit = 'years'
+        date_from = '2017'
+        date_from_format = '%Y'
+        date_to = '2017'
+        date_to_format = '%Y'
+        start = curator.datetime_to_epoch(datetime(2017,  1,  1,  0,  0,  0))
+        end   = curator.datetime_to_epoch(datetime(2017, 12, 31, 23, 59, 59))
+        self.assertEqual((start,end),
+            curator.absolute_date_range(unit, date_from, date_to, date_from_format, date_to_format))
+    def test_multiple_year(self):
+        unit = 'years'
+        date_from = '2016'
+        date_from_format = '%Y'
+        date_to = '2017'
+        date_to_format = '%Y'
+        start = curator.datetime_to_epoch(datetime(2016,  1,  1,  0,  0,  0))
+        end   = curator.datetime_to_epoch(datetime(2017, 12, 31, 23, 59, 59))
+        self.assertEqual((start,end),
+            curator.absolute_date_range(unit, date_from, date_to, date_from_format, date_to_format))
+    def test_single_week_UW(self):
+        unit = 'weeks'
+        date_from = '2017-01'
+        date_from_format = '%Y-%U'
+        date_to = '2017-01'
+        date_to_format = '%Y-%U'
+        start = curator.datetime_to_epoch(datetime(2017,  1,  2,  0,  0,  0))
+        end   = curator.datetime_to_epoch(datetime(2017,  1,  8, 23, 59, 59))
+        self.assertEqual((start,end),
+            curator.absolute_date_range(unit, date_from, date_to, date_from_format, date_to_format))
+    def test_multiple_weeks_UW(self):
+        unit = 'weeks'
+        date_from = '2017-01'
+        date_from_format = '%Y-%U'
+        date_to = '2017-04'
+        date_to_format = '%Y-%U'
+        start = curator.datetime_to_epoch(datetime(2017,  1,   2,  0,  0,  0))
+        end   = curator.datetime_to_epoch(datetime(2017,  1,  29, 23, 59, 59))
+        self.assertEqual((start,end),
+            curator.absolute_date_range(unit, date_from, date_to, date_from_format, date_to_format))
+    def test_single_week_ISO(self):
+        unit = 'weeks'
+        date_from = '2014-01'
+        date_from_format = '%G-%V'
+        date_to = '2014-01'
+        date_to_format = '%G-%V'
+        start = curator.datetime_to_epoch(datetime(2013, 12, 30,  0,  0,  0))
+        end   = curator.datetime_to_epoch(datetime(2014,  1,  5, 23, 59, 59))
+        self.assertEqual((start,end),
+            curator.absolute_date_range(unit, date_from, date_to, date_from_format, date_to_format))
+    def test_multiple_weeks_ISO(self):
+        unit = 'weeks'
+        date_from = '2014-01'
+        date_from_format = '%G-%V'
+        date_to = '2014-04'
+        date_to_format = '%G-%V'
+        start = curator.datetime_to_epoch(datetime(2013, 12, 30,  0,  0,  0))
+        end   = curator.datetime_to_epoch(datetime(2014,  1, 26, 23, 59, 59))
+        self.assertEqual((start,end),
+            curator.absolute_date_range(unit, date_from, date_to, date_from_format, date_to_format))
+    def test_single_day(self):
+        unit = 'days'
+        date_from = '2017.01.01'
+        date_from_format = '%Y.%m.%d'
+        date_to = '2017.01.01'
+        date_to_format = '%Y.%m.%d'
+        start = curator.datetime_to_epoch(datetime(2017,  1,  1,  0,  0,  0))
+        end   = curator.datetime_to_epoch(datetime(2017,  1,  1, 23, 59, 59))
+        self.assertEqual((start,end),
+            curator.absolute_date_range(unit, date_from, date_to, date_from_format, date_to_format))
+    def test_multiple_days(self):
+        unit = 'days'
+        date_from = '2016.12.31'
+        date_from_format = '%Y.%m.%d'
+        date_to = '2017.01.01'
+        date_to_format = '%Y.%m.%d'
+        start = curator.datetime_to_epoch(datetime(2016, 12, 31,  0,  0,  0))
+        end   = curator.datetime_to_epoch(datetime(2017,  1,  1, 23, 59, 59))
+        self.assertEqual((start,end),
+            curator.absolute_date_range(unit, date_from, date_to, date_from_format, date_to_format))
+    def test_ISO8601(self):
+        unit = 'seconds'
+        date_from = '2017-01-01T00:00:00'
+        date_from_format = '%Y-%m-%dT%H:%M:%S'
+        date_to = '2017-01-01T12:34:56'
+        date_to_format = '%Y-%m-%dT%H:%M:%S'
+        start = curator.datetime_to_epoch(datetime(2017,  1,  1,  0,  0,  0))
+        end   = curator.datetime_to_epoch(datetime(2017,  1,  1, 12, 34, 56))
+        self.assertEqual((start,end),
+            curator.absolute_date_range(unit, date_from, date_to, date_from_format, date_to_format))
+
 class TestNodeRoles(TestCase):
     def test_node_roles(self):
         node_id = u'my_node'
@@ -1105,3 +1266,34 @@ class TestNodeIdToName(TestCase):
         client = Mock()
         client.nodes.stats.return_value = {u'nodes':{'my_node_id':{u'name':'my_node_name'}}}
         self.assertIsNone(curator.node_id_to_name(client, 'not_my_node_id'))
+
+class TestIsDateMath(TestCase):
+    def test_positive(self):
+        data = '<encapsulated>'
+        self.assertTrue(curator.isdatemath(data))
+    def test_negative(self):
+        data = 'not_encapsulated'
+        self.assertFalse(curator.isdatemath(data))
+    def test_raises(self):
+        data = '<badly_encapsulated'
+        self.assertRaises(curator.ConfigurationError, curator.isdatemath, data)
+
+class TestGetDateMath(TestCase):
+    def test_success(self):
+        client = Mock()
+        datemath = u'{hasthemath}'
+        psuedo_random = u'not_random_at_all'
+        expected = u'curator_get_datemath_function_' + psuedo_random + u'-hasthemath'
+        client.indices.get.side_effect = (
+            elasticsearch.NotFoundError(
+                404, "simulated error", {u'error':{u'index':expected}})
+        )
+        self.assertEqual('hasthemath', curator.get_datemath(client, datemath, psuedo_random))
+    def test_failure(self):
+        client = Mock()
+        datemath = u'{hasthemath}'
+        client.indices.get.side_effect = (
+            elasticsearch.NotFoundError(
+                404, "simulated error", {u'error':{u'index':'failure'}})
+        )
+        self.assertRaises(curator.ConfigurationError, curator.get_datemath, client, datemath)
