@@ -3,11 +3,8 @@
 BASEPATH=$(pwd)
 PKG_TARGET=/curator_packages
 WORKDIR=/tmp/curator
-CX_VER="5.0.1"
-CX_FILE="/curator_source/unix_packages/cx_freeze-${CX_VER}.dev.tar.gz"
-CX_PATH="anthony_tuininga-cx_freeze-0e565139e6a3"
 PYVER=3.6
-MINOR=2
+MINOR=8
 INPUT_TYPE=python
 CATEGORY=python
 VENDOR=Elastic
@@ -78,7 +75,7 @@ if [ "${1}x" == "x" ]; then
   echo "Must provide version number (can be arbitrary)"
   exit 1
 else
-  cd ..
+  cd $(dirname $0)/..
   SOURCE_DIR=$(pwd)
 fi
 
@@ -110,6 +107,13 @@ case "$ID" in
   *) echo "unknown system type: ${ID}"; exit 1;;
 esac
 
+# Improve RPM dependency for RHEL/Centos 7
+if [ "$VERSION_ID" == "7" ] && [ "$PLATFORM" == "centos" ]; then
+  DEP1='openssl-libs >= 1:1.0.2k-8.el7'
+else
+  DEP1=''
+fi
+
 HAS_PY3=$(which python${PYVER})
 if [ "${HAS_PY3}x" == "x" ]; then
   build_python ${PYVER}.${MINOR}
@@ -138,14 +142,8 @@ fi
 
 ${PIPBIN} install -U --user setuptools
 ${PIPBIN} install -U --user requests_aws4auth
-if [ "${CX_VER}" != "$(${PIPBIN} list | grep cx | awk '{print $2}' | tr -d '()')" ]; then
-  cd ${WORKDIR}
-  rm -rf ${CX_PATH}
-  tar zxf ${CX_FILE}
-  cd ${CX_PATH}
-  ${PIPBIN} install -U --user .
-  cd ${WORKDIR}
-fi
+${PIPBIN} install -U --user boto3
+${PIPBIN} install -U --user cx_freeze
 
 cd $SOURCE_DIR
 
@@ -156,6 +154,8 @@ sudo mv build/exe.linux-x86_64-${PYVER} /opt/elasticsearch-curator
 
 sudo chown -R root:root /opt/elasticsearch-curator
 cd $WORKDIR
+
+if [ "x${DEP1}" == "x" ]; then
 fpm \
  -s dir \
  -t ${PKGTYPE} \
@@ -176,6 +176,30 @@ fpm \
  --conflicts python3-elasticsearch-curator \
 /opt/elasticsearch-curator
 
+else
+
+fpm \
+ -s dir \
+ -t ${PKGTYPE} \
+ -n elasticsearch-curator \
+ -v ${1} \
+ --vendor ${VENDOR} \
+ --maintainer "${MAINTAINER}" \
+ --license 'Apache-2.0' \
+ --category tools \
+ --depends "${DEP1}" \
+ --description 'Have indices in Elasticsearch? This is the tool for you!\n\nLike a museum curator manages the exhibits and collections on display, \nElasticsearch Curator helps you curate, or manage your indices.' \
+ --after-install ${C_POST_INSTALL} \
+ --before-remove ${C_PRE_REMOVE} \
+ --after-remove ${C_POST_REMOVE} \
+ --before-upgrade ${C_PRE_UPGRADE} \
+ --after-upgrade ${C_POST_UPGRADE} \
+ --provides elasticsearch-curator \
+ --conflicts python-elasticsearch-curator \
+ --conflicts python3-elasticsearch-curator \
+/opt/elasticsearch-curator
+fi
+
 mv ${WORKDIR}/*.${PKGTYPE} ${PACKAGEDIR}
 
 rm ${C_POST_INSTALL} ${C_PRE_REMOVE} ${C_POST_REMOVE} ${C_PRE_UPGRADE} ${C_POST_UPGRADE}
